@@ -1,5 +1,6 @@
 from pulumi import ComponentResource, ResourceOptions, StackReference
-from resources import resource_group
+from pulumi_azure_native import storage
+from resources import resource_group, storage_account
 import pulumi
 from pulumi import Output
 
@@ -15,8 +16,12 @@ class Bootstrap(ComponentResource):
         resource_group.self = self
 
         # Create bootstrap resource group
-        # bootstrap_rg = resource_group.resource_group('bootstrap', props)
-        shared_res_grp = resource_group.resource_group("Novari-Shared", props)
+        bootstrap_rg = resource_group.resource_group('pulumi-bootstrap', props)
 
+        # Create Storage account for state management
+        bootstrap_sa = storage_account.storage_account('pulumi-state', props)
+
+        # Create Storage container 
+        bootstrap_bc = storage_account.container('pulumi-state', props, bootstrap_sa)
 
         self.register_outputs({})
\ No newline at end of file
