@@ -8,6 +8,6 @@ def resource_group(stem, props, depends_on=None):
         resource_group_name=f'rg-{stem}',
         tags=props.tags,
         location=props.location,
-        opts=ResourceOptions(parent=self,depends_on=depends_on)
+        opts=ResourceOptions(depends_on=depends_on)
     )
     return rg
\ No newline at end of file
