@@ -9,7 +9,7 @@ import pulumi_azure_native.network as network
 # vdc.suffix = props.suffix
 # vdc.tags = props.tags
 
-def virtual_network(stem, address_spaces):
+def virtual_network(stem, address_spaces, depends_on=None,):
     vn = network.VirtualNetwork(
         f'vn-{stem}',
         virtual_network_name=f'vn-{stem}',
@@ -18,7 +18,7 @@ def virtual_network(stem, address_spaces):
             address_prefixes=address_spaces,
         ),
         tags=tags,
-        opts=ResourceOptions(parent=self),
+        opts=ResourceOptions(parent=self, depends_on=depends_on),
     )
     return vn
 
